@@ -152,233 +152,337 @@ extern "C" {
 
 /* \} name SECTION: Module configuration options */
 
-
-#if MYNEWT_VAL(MBEDTLS_ECP_ALT) == 0
 #undef MBEDTLS_ECP_ALT
+#if MYNEWT_VAL(MBEDTLS_ECP_ALT) == 1
+#define MBEDTLS_ECP_ALT
 #endif
-#if MYNEWT_VAL(MBEDTLS_ECP_RESTARTABLE) == 0
+
 #undef MBEDTLS_ECP_RESTARTABLE
+#if MYNEWT_VAL(MBEDTLS_ECP_RESTARTABLE)
+#define MBEDTLS_ECP_RESTARTABLE
 #endif
 
-#if MYNEWT_VAL(MBEDTLS_ECDH_GEN_PUBLIC_ALT) == 0
 #undef MBEDTLS_ECDH_GEN_PUBLIC_ALT
+#if MYNEWT_VAL(MBEDTLS_ECDH_GEN_PUBLIC_ALT)
+#define MBEDTLS_ECDH_GEN_PUBLIC_ALT
 #endif
-#if MYNEWT_VAL(MBEDTLS_ECDH_COMPUTE_SHARED_ALT) == 0
+
 #undef MBEDTLS_ECDH_COMPUTE_SHARED_ALT
+#if MYNEWT_VAL(MBEDTLS_ECDH_COMPUTE_SHARED_ALT)
+#define MBEDTLS_ECDH_COMPUTE_SHARED_ALT
 #endif
 
-#if MYNEWT_VAL(MBEDTLS_ECDSA_SIGN_ALT) == 0
 #undef MBEDTLS_ECDSA_SIGN_ALT
+#if MYNEWT_VAL(MBEDTLS_ECDSA_SIGN_ALT)
+#define MBEDTLS_ECDSA_SIGN_ALT
 #endif
-#if MYNEWT_VAL(MBEDTLS_ECDSA_VERIFY_ALT) == 0
+
 #undef MBEDTLS_ECDSA_VERIFY_ALT
+#if MYNEWT_VAL(MBEDTLS_ECDSA_VERIFY_ALT)
+#define MBEDTLS_ECDSA_VERIFY_ALT
 #endif
-#if MYNEWT_VAL(MBEDTLS_ECDSA_GENKEY_ALT) == 0
+
 #undef MBEDTLS_ECDSA_GENKEY_ALT
+#if MYNEWT_VAL(MBEDTLS_ECDSA_GENKEY_ALT)
+#define MBEDTLS_ECDSA_GENKEY_ALT
 #endif
 
 /* Enable support for configured curves only */
-#if MYNEWT_VAL(MBEDTLS_ECP_DP_SECP192R1) == 0
 #undef MBEDTLS_ECP_DP_SECP192R1_ENABLED
+#if MYNEWT_VAL(MBEDTLS_ECP_DP_SECP192R1)
+#define MBEDTLS_ECP_DP_SECP192R1_ENABLED
 #endif
-#if MYNEWT_VAL(MBEDTLS_ECP_DP_SECP224R1) == 0
+
 #undef MBEDTLS_ECP_DP_SECP224R1_ENABLED
+#if MYNEWT_VAL(MBEDTLS_ECP_DP_SECP224R1)
+#define MBEDTLS_ECP_DP_SECP224R1_ENABLED
 #endif
-#if MYNEWT_VAL(MBEDTLS_ECP_DP_SECP256R1) == 0
+
 #undef MBEDTLS_ECP_DP_SECP256R1_ENABLED
+#if MYNEWT_VAL(MBEDTLS_ECP_DP_SECP256R1)
+#define MBEDTLS_ECP_DP_SECP256R1_ENABLED
 #endif
-#if MYNEWT_VAL(MBEDTLS_ECP_DP_SECP384R1) == 0
+
 #undef MBEDTLS_ECP_DP_SECP384R1_ENABLED
+#if MYNEWT_VAL(MBEDTLS_ECP_DP_SECP384R1)
+#define MBEDTLS_ECP_DP_SECP384R1_ENABLED
 #endif
-#if MYNEWT_VAL(MBEDTLS_ECP_DP_SECP521R1) == 0
+
 #undef MBEDTLS_ECP_DP_SECP521R1_ENABLED
+#if MYNEWT_VAL(MBEDTLS_ECP_DP_SECP521R1)
+#define MBEDTLS_ECP_DP_SECP521R1_ENABLED
 #endif
-#if MYNEWT_VAL(MBEDTLS_ECP_DP_SECP192K1) == 0
+
 #undef MBEDTLS_ECP_DP_SECP192K1_ENABLED
+#if MYNEWT_VAL(MBEDTLS_ECP_DP_SECP192K1)
+#define MBEDTLS_ECP_DP_SECP192K1_ENABLED
 #endif
-#if MYNEWT_VAL(MBEDTLS_ECP_DP_SECP224K1) == 0
+
 #undef MBEDTLS_ECP_DP_SECP224K1_ENABLED
+#if MYNEWT_VAL(MBEDTLS_ECP_DP_SECP224K1)
+#define MBEDTLS_ECP_DP_SECP224K1_ENABLED
 #endif
-#if MYNEWT_VAL(MBEDTLS_ECP_DP_SECP256K1) == 0
+
 #undef MBEDTLS_ECP_DP_SECP256K1_ENABLED
+#if MYNEWT_VAL(MBEDTLS_ECP_DP_SECP256K1)
+#define MBEDTLS_ECP_DP_SECP256K1_ENABLED
 #endif
-#if MYNEWT_VAL(MBEDTLS_ECP_DP_BP256R1) == 0
+
 #undef MBEDTLS_ECP_DP_BP256R1_ENABLED
+#if MYNEWT_VAL(MBEDTLS_ECP_DP_BP256R1)
+#define MBEDTLS_ECP_DP_BP256R1_ENABLED
 #endif
-#if MYNEWT_VAL(MBEDTLS_ECP_DP_BP384R1) == 0
+
 #undef MBEDTLS_ECP_DP_BP384R1_ENABLED
+#if MYNEWT_VAL(MBEDTLS_ECP_DP_BP384R1)
+#define MBEDTLS_ECP_DP_BP384R1_ENABLED
 #endif
-#if MYNEWT_VAL(MBEDTLS_ECP_DP_BP512R1) == 0
+
 #undef MBEDTLS_ECP_DP_BP512R1_ENABLED
+#if MYNEWT_VAL(MBEDTLS_ECP_DP_BP512R1)
+#define MBEDTLS_ECP_DP_BP512R1_ENABLED
 #endif
-#if MYNEWT_VAL(MBEDTLS_ECP_DP_CURVE25519) == 0
+
 #undef MBEDTLS_ECP_DP_CURVE25519_ENABLED
+#if MYNEWT_VAL(MBEDTLS_ECP_DP_CURVE25519)
+#define MBEDTLS_ECP_DP_CURVE25519_ENABLED
 #endif
-#if MYNEWT_VAL(MBEDTLS_ECP_DP_CURVE448) == 0
+
 #undef MBEDTLS_ECP_DP_CURVE448_ENABLED
+#if MYNEWT_VAL(MBEDTLS_ECP_DP_CURVE448)
+#define MBEDTLS_ECP_DP_CURVE448_ENABLED
 #endif
 
-#if MYNEWT_VAL(MBEDTLS_ECJPAKE_C) == 0
 #undef MBEDTLS_ECJPAKE_C
+#if MYNEWT_VAL(MBEDTLS_ECJPAKE_C)
+#define MBEDTLS_ECJPAKE_C
 #endif
 
-#if MYNEWT_VAL(MBEDTLS_AES_ALT) == 0
 #undef MBEDTLS_AES_ALT
+#if MYNEWT_VAL(MBEDTLS_AES_ALT)
+#define MBEDTLS_AES_ALT
 #endif
-#if MYNEWT_VAL(MBEDTLS_AES_C) == 0
+
 #undef MBEDTLS_AES_C
+#if MYNEWT_VAL(MBEDTLS_AES_C)
+#define MBEDTLS_AES_C
 #endif
+
+#undef MBEDTLS_AES_ROM_TABLES
 #if MYNEWT_VAL(MBEDTLS_AES_ROM_TABLES)
 #define MBEDTLS_AES_ROM_TABLES
-#else
-#undef MBEDTLS_AES_ROM_TABLES
 #endif
+
+#undef MBEDTLS_AES_FEWER_TABLES
 #if MYNEWT_VAL(MBEDTLS_AES_FEWER_TABLES)
 #define MBEDTLS_AES_FEWER_TABLES
-#else
-#undef MBEDTLS_AES_FEWER_TABLES
 #endif
-#if MYNEWT_VAL(MBEDTLS_ARC4_C) == 0
+
 #undef MBEDTLS_ARC4_C
+#if MYNEWT_VAL(MBEDTLS_ARC4_C)
+#define MBEDTLS_ARC4_C
 #endif
-#if MYNEWT_VAL(MBEDTLS_ARIA_C) == 0
+
 #undef MBEDTLS_ARIA_C
+#if MYNEWT_VAL(MBEDTLS_ARIA_C)
+#define MBEDTLS_ARIA_C
 #endif
-#if MYNEWT_VAL(MBEDTLS_BLOWFISH_C) == 0
+
 #undef MBEDTLS_BLOWFISH_C
+#if MYNEWT_VAL(MBEDTLS_BLOWFISH_C)
+#define MBEDTLS_BLOWFISH_C
 #endif
-#if MYNEWT_VAL(MBEDTLS_CAMELLIA_C) == 0
+
 #undef MBEDTLS_CAMELLIA_C
+#if MYNEWT_VAL(MBEDTLS_CAMELLIA_C)
+#define MBEDTLS_CAMELLIA_C
 #endif
-#if MYNEWT_VAL(MBEDTLS_DES_C) == 0
+
 #undef MBEDTLS_DES_C
+#if MYNEWT_VAL(MBEDTLS_DES_C)
+#define MBEDTLS_DES_C
 #endif
 
-#if MYNEWT_VAL(MBEDTLS_NIST_KW_C) == 0
 #undef MBEDTLS_NIST_KW_C
+#if MYNEWT_VAL(MBEDTLS_NIST_KW_C)
+#define MBEDTLS_NIST_KW_C
 #endif
 
-#if MYNEWT_VAL(MBEDTLS_CHACHA20_C) == 0
 #undef MBEDTLS_CHACHA20_C
+#if MYNEWT_VAL(MBEDTLS_CHACHA20_C)
+#define MBEDTLS_CHACHA20_C
 #endif
-#if MYNEWT_VAL(MBEDTLS_CHACHAPOLY_C) == 0
+
 #undef MBEDTLS_CHACHAPOLY_C
+#if MYNEWT_VAL(MBEDTLS_CHACHAPOLY_C)
+#define MBEDTLS_CHACHAPOLY_C
 #endif
 
-#if MYNEWT_VAL(MBEDTLS_POLY1305_C) == 0
 #undef MBEDTLS_POLY1305_C
+#if MYNEWT_VAL(MBEDTLS_POLY1305_C)
+#define MBEDTLS_POLY1305_C
 #endif
 
-#if MYNEWT_VAL(MBEDTLS_CMAC_C) == 0
 #undef MBEDTLS_CMAC_C
+#if MYNEWT_VAL(MBEDTLS_CMAC_C)
+#define MBEDTLS_CMAC_C
 #endif
 
-#if MYNEWT_VAL(MBEDTLS_CIPHER_MODE_CBC) == 0
 #undef MBEDTLS_CIPHER_MODE_CBC
+#if MYNEWT_VAL(MBEDTLS_CIPHER_MODE_CBC)
+#define MBEDTLS_CIPHER_MODE_CBC
 #endif
-#if MYNEWT_VAL(MBEDTLS_CIPHER_MODE_CFB) == 0
+
 #undef MBEDTLS_CIPHER_MODE_CFB
+#if MYNEWT_VAL(MBEDTLS_CIPHER_MODE_CFB)
+#define MBEDTLS_CIPHER_MODE_CFB
 #endif
-#if MYNEWT_VAL(MBEDTLS_CIPHER_MODE_CTR) == 0
+
 #undef MBEDTLS_CIPHER_MODE_CTR
+#if MYNEWT_VAL(MBEDTLS_CIPHER_MODE_CTR)
+#define MBEDTLS_CIPHER_MODE_CTR
 #endif
-#if MYNEWT_VAL(MBEDTLS_CIPHER_MODE_OFB) == 0
+
 #undef MBEDTLS_CIPHER_MODE_OFB
+#if MYNEWT_VAL(MBEDTLS_CIPHER_MODE_OFB)
+#define MBEDTLS_CIPHER_MODE_OFB
 #endif
-#if MYNEWT_VAL(MBEDTLS_CIPHER_MODE_XTS) == 0
+
 #undef MBEDTLS_CIPHER_MODE_XTS
+#if MYNEWT_VAL(MBEDTLS_CIPHER_MODE_XTS)
+#define MBEDTLS_CIPHER_MODE_XTS
 #endif
-#if MYNEWT_VAL(MBEDTLS_CCM_C) == 0
+
 #undef MBEDTLS_CCM_C
+#if MYNEWT_VAL(MBEDTLS_CCM_C)
+#define MBEDTLS_CCM_C
 #endif
 
-#if MYNEWT_VAL(MBEDTLS_CTR_DRBG_C) == 0
 #undef MBEDTLS_CTR_DRBG_C
+#if MYNEWT_VAL(MBEDTLS_CTR_DRBG_C)
+#define MBEDTLS_CTR_DRBG_C
 #endif
 
-#if MYNEWT_VAL(MBEDTLS_SHA256_ALT) == 0
 #undef MBEDTLS_SHA256_ALT
-#elif !defined(MBEDTLS_SHA256_ALT)
-#define MBEDTLS_SHA256_ALT 1
+#if MYNEWT_VAL(MBEDTLS_SHA256_ALT)
+#define MBEDTLS_SHA256_ALT
 #endif
-#if MYNEWT_VAL(MBEDTLS_SHA256_C) == 0
+
 #undef MBEDTLS_SHA256_C
+#if MYNEWT_VAL(MBEDTLS_SHA256_C)
+#define MBEDTLS_SHA256_C
 #endif
-#if MYNEWT_VAL(MBEDTLS_MD2_C) == 0
+
 #undef MBEDTLS_MD2_C
+#if MYNEWT_VAL(MBEDTLS_MD2_C)
+#define MBEDTLS_MD2_C
 #endif
-#if MYNEWT_VAL(MBEDTLS_MD4_C) == 0
+
 #undef MBEDTLS_MD4_C
+#if MYNEWT_VAL(MBEDTLS_MD4_C)
+#define MBEDTLS_MD4_C
 #endif
-#if MYNEWT_VAL(MBEDTLS_MD5_C) == 0
+
 #undef MBEDTLS_MD5_C
+#if MYNEWT_VAL(MBEDTLS_MD5_C)
+#define MBEDTLS_MD5_C
 #endif
-#if MYNEWT_VAL(MBEDTLS_SHA1_C) == 0
+
 #undef MBEDTLS_SHA1_C
+#if MYNEWT_VAL(MBEDTLS_SHA1_C)
+#define MBEDTLS_SHA1_C
 #endif
-#if MYNEWT_VAL(MBEDTLS_SHA512_C) == 0
+
 #undef MBEDTLS_SHA512_C
+#if MYNEWT_VAL(MBEDTLS_SHA512_C)
+#define MBEDTLS_SHA512_C
 #endif
-#if MYNEWT_VAL(MBEDTLS_RIPEMD160_C) == 0
+
 #undef MBEDTLS_RIPEMD160_C
+#if MYNEWT_VAL(MBEDTLS_RIPEMD160_C)
+#define MBEDTLS_RIPEMD160_C
 #endif
 
-#if MYNEWT_VAL(MBEDTLS_MD5_C) == 0 && MYNEWT_VAL(MBEDTLS_SHA1_C) == 0
 #undef MBEDTLS_SSL_PROTO_TLS1
 #undef MBEDTLS_SSL_PROTO_TLS1_1
 #undef MBEDTLS_SSL_CBC_RECORD_SPLITTING
+#if MYNEWT_VAL(MBEDTLS_MD5_C) && MYNEWT_VAL(MBEDTLS_SHA1_C)
+#define MBEDTLS_SSL_PROTO_TLS1
+#define MBEDTLS_SSL_PROTO_TLS1_1
+#define MBEDTLS_SSL_CBC_RECORD_SPLITTING
 #endif
 
-#if MYNEWT_VAL(MBEDTLS_HKDF_C) == 0
 #undef MBEDTLS_HKDF_C
+#if MYNEWT_VAL(MBEDTLS_HKDF_C)
+#define MBEDTLS_HKDF_C
 #endif
 
-#if MYNEWT_VAL(MBEDTLS_BASE64_C) == 0
 #undef MBEDTLS_BASE64_C
+#if MYNEWT_VAL(MBEDTLS_BASE64_C)
+#define MBEDTLS_BASE64_C
 #endif
 
-#if MYNEWT_VAL(MBEDTLS_TIMING_C) == 0
 #undef MBEDTLS_TIMING_C
+#if MYNEWT_VAL(MBEDTLS_TIMING_C)
+#define MBEDTLS_TIMING_C
 #endif
 
-#if MYNEWT_VAL(MBEDTLS_ENTROPY_C) == 0
 #undef MBEDTLS_ENTROPY_C
+#if MYNEWT_VAL(MBEDTLS_ENTROPY_C)
+#define MBEDTLS_ENTROPY_C
 #endif
 
-#if MYNEWT_VAL(MBEDTLS_ENTROPY_HARDWARE_ALT) == 0
 #undef MBEDTLS_ENTROPY_HARDWARE_ALT
+#if MYNEWT_VAL(MBEDTLS_ENTROPY_HARDWARE_ALT)
+#define MBEDTLS_ENTROPY_HARDWARE_ALT
 #endif
 
-#if MYNEWT_VAL(MBEDTLS_PKCS1_V15) == 0
 #undef MBEDTLS_PKCS1_V15
+#if MYNEWT_VAL(MBEDTLS_PKCS1_V15)
+#define MBEDTLS_PKCS1_V15
 #endif
-#if MYNEWT_VAL(MBEDTLS_PKCS1_V21) == 0
+
 #undef MBEDTLS_PKCS1_V21
+#if MYNEWT_VAL(MBEDTLS_PKCS1_V21)
+#define MBEDTLS_PKCS1_V21
 #endif
 
-#if MYNEWT_VAL(MBEDTLS_GENPRIME) == 0
 #undef MBEDTLS_GENPRIME
+#if MYNEWT_VAL(MBEDTLS_GENPRIME)
+#define MBEDTLS_GENPRIME
 #endif
 
-#if MYNEWT_VAL(MBEDTLS_KEY_EXCHANGE_DHE_RSA_ENABLED) == 0
 #undef MBEDTLS_KEY_EXCHANGE_DHE_RSA_ENABLED
+#if MYNEWT_VAL(MBEDTLS_KEY_EXCHANGE_DHE_RSA_ENABLED)
+#define MBEDTLS_KEY_EXCHANGE_DHE_RSA_ENABLED
 #endif
-#if MYNEWT_VAL(MBEDTLS_KEY_EXCHANGE_ECDHE_RSA_ENABLED) == 0
+
 #undef MBEDTLS_KEY_EXCHANGE_ECDHE_RSA_ENABLED
+#if MYNEWT_VAL(MBEDTLS_KEY_EXCHANGE_ECDHE_RSA_ENABLED)
+#define MBEDTLS_KEY_EXCHANGE_ECDHE_RSA_ENABLED
 #endif
-#if MYNEWT_VAL(MBEDTLS_KEY_EXCHANGE_RSA_PSK_ENABLED) == 0
+
 #undef MBEDTLS_KEY_EXCHANGE_RSA_PSK_ENABLED
+#if MYNEWT_VAL(MBEDTLS_KEY_EXCHANGE_RSA_PSK_ENABLED)
+#define MBEDTLS_KEY_EXCHANGE_RSA_PSK_ENABLED
 #endif
-#if MYNEWT_VAL(MBEDTLS_KEY_EXCHANGE_RSA_ENABLED) == 0
+
 #undef MBEDTLS_KEY_EXCHANGE_RSA_ENABLED
+#if MYNEWT_VAL(MBEDTLS_KEY_EXCHANGE_RSA_ENABLED)
+#define MBEDTLS_KEY_EXCHANGE_RSA_ENABLED
 #endif
 
-#if MYNEWT_VAL(MBEDTLS_SSL_TLS_C) == 0
 #undef MBEDTLS_SSL_TLS_C
 #undef MBEDTLS_SSL_CLI_C
 #undef MBEDTLS_SSL_SRV_C
 #undef MBEDTLS_SSL_DTLS_ANTI_REPLAY
 #undef MBEDTLS_SSL_DTLS_BADMAC_LIMIT
+#if MYNEWT_VAL(MBEDTLS_SSL_TLS_C)
+#define MBEDTLS_SSL_TLS_C
+#define MBEDTLS_SSL_CLI_C
+#define MBEDTLS_SSL_SRV_C
+#define MBEDTLS_SSL_DTLS_ANTI_REPLAY
+#define MBEDTLS_SSL_DTLS_BADMAC_LIMIT
 #endif
 
 #if MYNEWT_VAL(MBEDTLS_MPI_MAX_SIZE) == 0
@@ -387,10 +491,17 @@ extern "C" {
 #define MBEDTLS_MPI_MAX_SIZE MYNEWT_VAL(MBEDTLS_MPI_MAX_SIZE)
 #endif
 
-#if MYNEWT_VAL(MBEDTLS_BIGNUM_ALT) == 0
 #undef MBEDTLS_BIGNUM_ALT
+#if MYNEWT_VAL(MBEDTLS_BIGNUM_ALT)
+#define MBEDTLS_BIGNUM_ALT
 #endif
 
+/* TODO configure when supported */
+#undef MBEDTLS_PSA_CRYPTO_C
+#undef MBEDTLS_PSA_CRYPTO_SE_C
+#undef MBEDTLS_PSA_CRYPTO_STORAGE_C
+#undef MBEDTLS_PSA_ITS_FILE_C
+
 #ifdef __cplusplus
 }
 #endif
