@@ -21,6 +21,7 @@
 #include <stddef.h>
 #include <assert.h>
 #include <os/mynewt.h>
+#include "mynewt_cm.h"
 #include <nrfx.h>
 #include <flash_map/flash_map.h>
 #include <hal/hal_bsp.h>
@@ -105,4 +106,5 @@ hal_bsp_init(void)
 void
 hal_bsp_deinit(void)
 {
+    Cortex_DisableAll();
 }
