@@ -51,7 +51,6 @@
   * @brief This is the list of modules to be used in the HAL driver 
   */
 #if 0
-#define HAL_MODULE_ENABLED
 #define HAL_ADC_MODULE_ENABLED
 #define HAL_COMP_MODULE_ENABLED
 #define HAL_CRC_MODULE_ENABLED
@@ -71,10 +70,11 @@
 #define HAL_SMARTCARD_MODULE_ENABLED
 #define HAL_SMBUS_MODULE_ENABLED
 #define HAL_WWDG_MODULE_ENABLED
-#define HAL_CORTEX_MODULE_ENABLED
 #define HAL_PCD_MODULE_ENABLED
 #endif
 
+#define HAL_MODULE_ENABLED
+#define HAL_CORTEX_MODULE_ENABLED
 #define HAL_FLASH_MODULE_ENABLED
 #define HAL_IWDG_MODULE_ENABLED
 #define HAL_GPIO_MODULE_ENABLED
@@ -91,7 +91,9 @@
   *        This value is used by the RCC HAL module to compute the system frequency
   *        (when HSE is used as system clock source, directly or through the PLL).  
   */
-#if !defined  (HSE_VALUE)
+#if defined (MYNEWT_VAL_STM32_CLOCK_HSE_VALUE)
+#define HSE_VALUE    MYNEWT_VAL(STM32_CLOCK_HSE_VALUE)
+#elif !defined  (HSE_VALUE)
   #define HSE_VALUE    ((uint32_t)8000000U) /*!< Value of the External oscillator in Hz */
 #endif /* HSE_VALUE */
 
@@ -158,8 +160,8 @@
 #define  TICK_INT_PRIORITY            (((uint32_t)1U<<__NVIC_PRIO_BITS) - 1U)    /*!< tick interrupt priority */
 #define  USE_RTOS                     0U
 #define  PREFETCH_ENABLE              MYNEWT_VAL(STM32_FLASH_PREFETCH_ENABLE)
-#define  INSTRUCTION_CACHE_ENABLE     MYNEWT_VAL(STM32_INSTRUCTION_CACHE_ENABLE)
-#define  DATA_CACHE_ENABLE            MYNEWT_VAL(STM32_DATA_CACHE_ENABLE)
+#define  PREREAD_ENABLE               MYNEWT_VAL(STM32_FLASH_PREREAD_ENABLE)
+#define  BUFFER_CACHE_DISABLE         (MYNEWT_VAL(STM32_FLASH_CACHE_ENABLE) == 0)
 
 /* ########################## Assert Selection ############################## */
 /**
