@@ -413,17 +413,13 @@ i2c_da1469x_enable(struct bus_dev *bdev)
 }
 
 static int
-i2c_da1469x_configure(struct bus_dev *bdev, struct bus_node *bnode)
+i2c_da1469x_configure_controller(struct bus_i2c_dev *dev, uint8_t address, uint16_t freq)
 {
-    struct bus_i2c_dev *dev = (struct bus_i2c_dev *)bdev;
-    struct bus_i2c_node *node = (struct bus_i2c_node *)bnode;
-    struct bus_i2c_node *current_node = (struct bus_i2c_node *)bdev->configured_for;
     I2C_Type *i2c_regs;
     uint32_t speed;
     int rc = 0;
 
     BUS_DEBUG_VERIFY_DEV(dev);
-    BUS_DEBUG_VERIFY_NODE(node);
 
     i2c_regs = da1469x_i2c[dev->cfg.i2c_num].regs;
 
@@ -431,13 +427,9 @@ i2c_da1469x_configure(struct bus_dev *bdev, struct bus_node *bnode)
         i2c_regs->I2C_ENABLE_REG &= ~(1U << I2C_I2C_ENABLE_REG_I2C_EN_Pos);
     }
 
-    i2c_regs->I2C_TAR_REG = node->addr & I2C_I2C_TAR_REG_IC_TAR_Msk;
+    i2c_regs->I2C_TAR_REG = address & I2C_I2C_TAR_REG_IC_TAR_Msk;
 
-    if (current_node && (current_node->freq == node->freq)) {
-        goto end;
-    }
-
-    switch (node->freq) {
+    switch (freq) {
     case 100:
         speed = 1;
         break;
@@ -457,6 +449,18 @@ end:
     return rc;
 }
 
+static int
+i2c_da1469x_configure(struct bus_dev *bdev, struct bus_node *bnode)
+{
+    struct bus_i2c_dev *dev = (struct bus_i2c_dev *)bdev;
+    struct bus_i2c_node *node = (struct bus_i2c_node *)bnode;
+
+    BUS_DEBUG_VERIFY_DEV(dev);
+    BUS_DEBUG_VERIFY_NODE(node);
+
+    return i2c_da1469x_configure_controller(dev, node->addr, node->freq);
+}
+
 static int
 i2c_da1469x_translate_abort(uint32_t abort_code)
 {
@@ -619,13 +623,97 @@ i2c_da1469x_disable(struct bus_dev *bdev)
     return 0;
 }
 
-static const struct bus_dev_ops bus_i2c_da1469x_dma_ops = {
-    .init_node = i2c_da1469x_init_node,
-    .enable = i2c_da1469x_enable,
-    .configure = i2c_da1469x_configure,
-    .read = i2c_da1469x_read,
-    .write = i2c_da1469x_write,
-    .disable = i2c_da1469x_disable,
+static int
+i2c_da1469x_probe(struct bus_i2c_dev *dev, uint16_t address, os_time_t timeout)
+{
+    I2C_Type *i2c_regs;
+    int rc;
+    int i;
+    int pin_sda;
+    int pin_scl;
+    uint32_t half_clock_ticks = os_cputime_usecs_to_ticks(5);
+    const struct da1469x_i2c_hw *i2c_hw;
+    int nack;
+    bool reenable = false;
+    BUS_DEBUG_VERIFY_DEV(dev);
+
+    rc = os_error_to_sys(os_mutex_pend(&dev->bdev.lock, timeout));
+    if (rc == 0) {
+        i2c_hw = &da1469x_i2c[dev->cfg.i2c_num];
+        i2c_regs = da1469x_i2c[dev->cfg.i2c_num].regs;
+
+        pin_scl = dev->cfg.pin_scl;
+        pin_sda = dev->cfg.pin_sda;
+        if (i2c_regs->I2C_ENABLE_REG & I2C_I2C_ENABLE_REG_I2C_EN_Msk) {
+            i2c_regs->I2C_ENABLE_REG &= ~(1U << I2C_I2C_ENABLE_REG_I2C_EN_Pos);
+            reenable = true;
+        }
+        hal_gpio_write(pin_scl, 1);
+        hal_gpio_write(pin_sda, 1);
+        mcu_gpio_set_pin_function(pin_scl, MCU_GPIO_MODE_OUTPUT_OPEN_DRAIN,
+                                  MCU_GPIO_FUNC_GPIO);
+        mcu_gpio_set_pin_function(pin_sda, MCU_GPIO_MODE_OUTPUT_OPEN_DRAIN,
+                                  MCU_GPIO_FUNC_GPIO);
+
+        /* Start condition */
+        hal_gpio_write(pin_sda, 0);
+        hal_gpio_write(pin_scl, 0);
+        address <<= 1;
+        os_cputime_delay_ticks(half_clock_ticks);
+        for (i = 7; i >= 0; --i) {
+            hal_gpio_write(pin_sda, address & (1 << i));
+            os_cputime_delay_ticks(half_clock_ticks);
+            hal_gpio_write(pin_scl, 1);
+            os_cputime_delay_ticks(half_clock_ticks);
+            hal_gpio_write(pin_scl, 0);
+        }
+        mcu_gpio_set_pin_function(pin_sda, MCU_GPIO_MODE_INPUT_PULLUP,
+                                  MCU_GPIO_FUNC_GPIO);
+        os_cputime_delay_ticks(half_clock_ticks);
+
+        hal_gpio_write(pin_scl, 1);
+        while (hal_gpio_read(pin_scl) == 0) ;
+        nack = hal_gpio_read(pin_sda);
+        os_cputime_delay_ticks(half_clock_ticks);
+        hal_gpio_write(pin_scl, 0);
+        /* Stop condition */
+        mcu_gpio_set_pin_function(pin_sda, MCU_GPIO_MODE_OUTPUT, MCU_GPIO_FUNC_GPIO);
+        hal_gpio_write(pin_sda, 0);
+        os_cputime_delay_ticks(half_clock_ticks);
+        hal_gpio_write(pin_scl, 1);
+        os_cputime_delay_ticks(half_clock_ticks);
+        hal_gpio_write(pin_sda, 1);
+        mcu_gpio_set_pin_function(pin_scl, MCU_GPIO_MODE_OUTPUT_OPEN_DRAIN,
+                                  MCU_GPIO_FUNC_GPIO);
+        mcu_gpio_set_pin_function(pin_sda, MCU_GPIO_MODE_OUTPUT_OPEN_DRAIN,
+                                  MCU_GPIO_FUNC_GPIO);
+
+        mcu_gpio_set_pin_function(pin_scl, MCU_GPIO_MODE_OUTPUT_OPEN_DRAIN,
+                                  i2c_hw->scl_func);
+        mcu_gpio_set_pin_function(pin_sda, MCU_GPIO_MODE_OUTPUT_OPEN_DRAIN,
+                                  i2c_hw->sda_func);
+        if (reenable) {
+            i2c_regs->I2C_ENABLE_REG |= ~(1U << I2C_I2C_ENABLE_REG_I2C_EN_Pos);
+        }
+        rc = nack ? SYS_ENOENT : 0;
+
+        (void)os_mutex_release(&dev->bdev.lock);
+    }
+
+    return rc;
+}
+
+
+static const struct i2c_dev_ops bus_i2c_da1469x_dma_ops = {
+    .bus_ops = {
+        .init_node = i2c_da1469x_init_node,
+        .enable = i2c_da1469x_enable,
+        .configure = i2c_da1469x_configure,
+        .read = i2c_da1469x_read,
+        .write = i2c_da1469x_write,
+        .disable = i2c_da1469x_disable,
+    },
+    .probe = i2c_da1469x_probe,
 };
 
 int
@@ -680,6 +768,7 @@ bus_i2c_da1469x_dev_init_func(struct os_dev *odev, void *arg)
 
     i2c_hw->regs->I2C_CON_REG = (1U << I2C_I2C_CON_REG_I2C_MASTER_MODE_Pos) |
                                 (1U << I2C_I2C_CON_REG_I2C_SPEED_Pos) |
+                                (1U << I2C_I2C_CON_REG_I2C_SLAVE_DISABLE_Pos) |
                                 (1U << I2C_I2C_CON_REG_I2C_RESTART_EN_Pos);
 
     i2c_hw->regs->I2C_INTR_MASK_REG = 0;
@@ -706,11 +795,11 @@ bus_i2c_da1469x_dev_init_func(struct os_dev *odev, void *arg)
 
 #if MYNEWT_VAL(I2C_DA1469X_STAT)
     asprintf(&stats_name, "i2c_da1469x_%d", cfg->i2c_num);
-    /* XXX should we assert or return error on failure? */
-    stats_init_and_reg(STATS_HDR(dd->stats),
-                       STATS_SIZE_INIT_PARMS(dd->stats, STATS_SIZE_32),
-                       STATS_NAME_INIT_PARMS(i2c_da1469x_stats_section),
-                       stats_name);
+    rc = stats_init_and_reg(STATS_HDR(dd->stats),
+                            STATS_SIZE_INIT_PARMS(dd->stats, STATS_SIZE_32),
+                            STATS_NAME_INIT_PARMS(i2c_da1469x_stats_section),
+                            stats_name);
+    assert(rc == 0);
 #endif
 
     rc = bus_dev_init_func(odev, (void*)&bus_i2c_da1469x_dma_ops);
