@@ -456,6 +456,7 @@ bus_i2c_nrf91_twim_read(struct bus_dev *bdev, struct bus_node *bnode,
          * XXX we may use PPI to workaround for missing shortcut but it's
          * probably not really that useful and not worth the effort.
          */
+        assert(0);
         return SYS_ENOTSUP;
     }
 
@@ -650,11 +651,11 @@ bus_i2c_nrf91_twim_dev_init_func(struct os_dev *odev, void *arg)
 
 #if MYNEWT_VAL(I2C_NRF91_TWIM_STAT)
     asprintf(&stats_name, "i2c_nrf91_twim%d", cfg->i2c_num);
-    /* XXX should we assert or return error on failure? */
-    stats_init_and_reg(STATS_HDR(dd->stats),
-                       STATS_SIZE_INIT_PARMS(dd->stats, STATS_SIZE_32),
-                       STATS_NAME_INIT_PARMS(twim_stats_section),
-                       stats_name);
+    rc = stats_init_and_reg(STATS_HDR(dd->stats),
+                            STATS_SIZE_INIT_PARMS(dd->stats, STATS_SIZE_32),
+                            STATS_NAME_INIT_PARMS(twim_stats_section),
+                            stats_name);
+    assert(rc == 0);
 #endif
 
     rc = bus_dev_init_func(odev, (void *)&bus_i2c_nrf91_twim_ops);
