@@ -252,6 +252,36 @@ bus_spi_write_read(struct bus_dev *bdev, struct bus_node *bnode,
     return rc;
 }
 
+static int
+bus_spi_duplex_write_read(struct bus_dev *bdev, struct bus_node *bnode,
+                          const uint8_t *wbuf, uint8_t *rbuf, uint16_t length,
+                          os_time_t timeout, uint16_t flags)
+{
+    struct bus_spi_hal_dev *dev = (struct bus_spi_hal_dev *)bdev;
+    struct bus_spi_node *node = (struct bus_spi_node *)bnode;
+    int rc;
+
+    BUS_DEBUG_VERIFY_DEV(&dev->spi_dev);
+    BUS_DEBUG_VERIFY_NODE(node);
+
+    hal_gpio_write(node->pin_cs, 0);
+
+#if MYNEWT_VAL(SPI_HAL_USE_NOBLOCK)
+    rc = hal_spi_txrx_noblock(dev->spi_dev.cfg.spi_num, (uint8_t *)wbuf, rbuf, length);
+    if (rc == 0) {
+        os_sem_pend(&dev->sem, OS_TIMEOUT_NEVER);
+    }
+#else
+    rc = hal_spi_txrx(dev->spi_dev.cfg.spi_num, (uint8_t *)wbuf, rbuf, length);
+#endif
+
+    if (rc || !(flags & BUS_F_NOSTOP)) {
+        hal_gpio_write(node->pin_cs, 1);
+    }
+
+    return rc;
+}
+
 static int bus_spi_disable(struct bus_dev *bdev)
 {
     struct bus_spi_dev *spi_dev = (struct bus_spi_dev *)bdev;
@@ -275,6 +305,7 @@ static const struct bus_dev_ops bus_spi_ops = {
     .write = bus_spi_write,
     .disable = bus_spi_disable,
     .write_read = bus_spi_write_read,
+    .duplex_write_read = bus_spi_duplex_write_read,
 };
 
 int
