@@ -32,6 +32,7 @@
 bool g_mcu_lpclk_available;
 
 static da1469x_lpclk_cb *g_da1469x_lpclk_cmac_cb;
+static uint32_t g_lpclk_last_freq = 0;
 
 #if MYNEWT_VAL_CHOICE(MCU_LPCLK_SOURCE, XTAL32K)
 static void
@@ -45,15 +46,20 @@ da1469x_lpclk_settle_tmr_cb(void *arg)
 static void
 da1469x_lpclk_notify(void)
 {
-    if (!g_da1469x_lpclk_cmac_cb || !g_mcu_lpclk_available) {
-        return;
-    }
+    uint32_t lp_curr_freq;
 
-#if MYNEWT_VAL_CHOICE(MCU_LPCLK_SOURCE, XTAL32K)
-    g_da1469x_lpclk_cmac_cb(32768);
-#elif MYNEWT_VAL_CHOICE(MCU_LPCLK_SOURCE, RCX)
-    g_da1469x_lpclk_cmac_cb(da1469x_clock_lp_rcx_freq_get());
-#endif
+    lp_curr_freq = da1469x_clock_lp_freq_get();
+
+    if (lp_curr_freq != g_lpclk_last_freq) {
+        g_lpclk_last_freq = lp_curr_freq;
+
+        if (g_da1469x_lpclk_cmac_cb && g_mcu_lpclk_available) {
+            g_da1469x_lpclk_cmac_cb(lp_curr_freq);
+        }
+
+        da1469x_clock_lp_set_rtc_divs(lp_curr_freq);
+        hal_os_tick_calc_params(lp_curr_freq);
+    }
 }
 
 void
@@ -76,6 +82,31 @@ da1469x_lpclk_updated(void)
     da1469x_lpclk_notify();
 }
 
+void
+da1469x_lpclk_rc_init(void)
+{
+#if MYNEWT_VAL_CHOICE(MCU_LPCLK_SOURCE, RCX)
+    da1469x_clock_lp_rc32k_disable();
+    da1469x_clock_lp_rcx_enable();
+    da1469x_clock_lp_rcx_switch();
+    da1469x_clock_lp_calibrate();
+    da1469x_lpclk_enabled();
+#elif MYNEWT_VAL_CHOICE(MCU_LPCLK_SOURCE, RC32K)
+    da1469x_clock_lp_rcx_disable();
+    da1469x_clock_lp_rc32k_enable();
+    da1469x_clock_lp_rc32k_switch();
+    da1469x_clock_lp_calibrate();
+    da1469x_lpclk_enabled();
+#elif MYNEWT_VAL_CHOICE(MCU_LPCLK_SOURCE, XTAL32K)
+    /*
+     * We cannot switch lp_clk to XTAL32K here since it needs some time to
+     * settle, so we just disable RCX (we don't need it) and then we'll handle
+     * switch to XTAL32K from sysinit since we need os_cputime for this.
+     */
+    da1469x_clock_lp_rcx_disable();
+#endif
+}
+
 void
 da1469x_lpclk_init(void)
 {
