@@ -90,6 +90,13 @@ struct da1469x_uart_baudrate {
 };
 
 static const struct da1469x_uart_baudrate da1469x_uart_baudrates[] = {
+#if MYNEWT_VAL_CHOICE(MCU_SYSCLK_SOURCE, PLL96)
+#if MYNEWT_VAL(UART_1) || MYNEWT_VAL(UART_2)
+    { 6000000, 0x00000100 },
+    { 3000000, 0x00000200 },
+#endif
+#endif
+    { 2000000, 0x00000100 },
     { 1000000, 0x00000200 },
     {  921600, 0x00000203 },
     {  500000, 0x00000400 },
@@ -142,6 +149,12 @@ da1469x_uart_tx_intr_disable(struct da1469x_uart *uart)
                                        UART2_UART2_IER_DLH_REG_ETBEI_DLH1_Msk);
 }
 
+static inline void
+da1469x_uart_tx_pthre_intr_disable(struct da1469x_uart *uart)
+{
+    uart->regs->UART2_IER_DLH_REG &= ~UART2_UART2_IER_DLH_REG_PTIME_DLH7_Msk;
+}
+
 static inline void
 da1469x_uart_rx_intr_enable(struct da1469x_uart *uart)
 {
@@ -183,15 +196,19 @@ da1469x_uart_isr_thr_empty(struct da1469x_uart *uart)
 
     regs = uart->regs;
 
+    if (!uart->tx_started) {
+        da1469x_uart_tx_intr_disable(uart);
+        if (uart->tx_done) {
+            uart->tx_done(uart->func_arg);
+        }
+        return;
+    }
+
     while (regs->UART2_USR_REG & UART2_UART2_USR_REG_UART_TFNF_Msk) {
         ch = uart->tx_func(uart->func_arg);
         if (ch < 0) {
-            da1469x_uart_tx_intr_disable(uart);
+            da1469x_uart_tx_pthre_intr_disable(uart);
             uart->tx_started = 0;
-            if (uart->tx_done) {
-                uart->tx_done(uart->func_arg);
-            }
-
             break;
         }
 
@@ -513,29 +530,41 @@ hal_uart_config(int port, int32_t baudrate, uint8_t databits, uint8_t stopbits,
         return SYS_EINVAL;
     }
 
+    /* Check baudrate */
+    baudrate_cfg = da1469x_uart_find_baudrate_cfg(baudrate);
+    if (!baudrate_cfg || ((port == 0) && (baudrate > 2000000))) {
+        return SYS_ENOTSUP;
+    }
+
     switch (port) {
     case 0:
         CRG_COM->SET_CLK_COM_REG = CRG_COM_SET_CLK_COM_REG_UART_ENABLE_Msk;
         break;
     case 1:
         CRG_COM->SET_CLK_COM_REG = CRG_COM_SET_CLK_COM_REG_UART2_ENABLE_Msk;
-        CRG_COM->RESET_CLK_COM_REG = CRG_COM_SET_CLK_COM_REG_UART2_CLK_SEL_Msk;
+        if (baudrate <= 2000000) {
+            /* Use DIVN as clock source */
+            CRG_COM->RESET_CLK_COM_REG = CRG_COM_SET_CLK_COM_REG_UART2_CLK_SEL_Msk;
+        } else {
+            /* Use DIV1 as clock source */
+            CRG_COM->SET_CLK_COM_REG = CRG_COM_SET_CLK_COM_REG_UART2_CLK_SEL_Msk;
+        }
         break;
     case 2:
         CRG_COM->SET_CLK_COM_REG = CRG_COM_SET_CLK_COM_REG_UART3_ENABLE_Msk;
-        CRG_COM->RESET_CLK_COM_REG = CRG_COM_SET_CLK_COM_REG_UART3_CLK_SEL_Msk;
+        if (baudrate <= 2000000) {
+            /* Use DIVN as clock source */
+            CRG_COM->RESET_CLK_COM_REG = CRG_COM_SET_CLK_COM_REG_UART3_CLK_SEL_Msk;
+        } else {
+            /* Use DIV1 as clock source */
+            CRG_COM->SET_CLK_COM_REG = CRG_COM_SET_CLK_COM_REG_UART3_CLK_SEL_Msk;
+        }
         break;
     default:
         assert(0);
         break;
     }
 
-    /* Set baudrate */
-    baudrate_cfg = da1469x_uart_find_baudrate_cfg(baudrate);
-    if (!baudrate_cfg) {
-        return SYS_ENOTSUP;
-    }
-
     if (uart->cfg->pin_rx >= 0) {
         /*
          * Switch to GPIO during configuration to prevent landing up in
@@ -543,6 +572,10 @@ hal_uart_config(int port, int32_t baudrate, uint8_t databits, uint8_t stopbits,
          */
         da1469x_uart_set_rx_pin_as_gpio(uart);
     }
+    /* Reset UART before setting up new baudrate */
+    regs->UART2_SRR_REG = UART2_UART2_SRR_REG_UART_UR_Msk |
+                          UART2_UART2_SRR_REG_UART_RFR_Msk |
+                          UART2_UART2_SRR_REG_UART_XFR_Msk;
 
     regs->UART2_LCR_REG |= UART2_UART2_LCR_REG_UART_DLAB_Msk;
     regs->UART2_IER_DLH_REG = (baudrate_cfg >> 16) & 0xff;
@@ -571,7 +604,7 @@ hal_uart_config(int port, int32_t baudrate, uint8_t databits, uint8_t stopbits,
     /* Enable hardware FIFO */
     regs->UART2_SFE_REG = UART2_UART2_SFE_REG_UART_SHADOW_FIFO_ENABLE_Msk;
     regs->UART2_SRT_REG = 0;
-    regs->UART2_STET_REG = 0;
+    regs->UART2_STET_REG = 3;
 
     /* Enable flow-control if requested and supported */
     if (flow_ctl == HAL_UART_FLOW_CTL_RTS_CTS) {
