@@ -20,11 +20,12 @@
 #include <string.h>
 #include <assert.h>
 #include <stdint.h>
+#include <syscfg/syscfg.h>
 #if MYNEWT_VAL(QSPI_ENABLE)
 #include <hal/hal_flash_int.h>
 #include "mcu/nrf5340_hal.h"
 #include "nrf.h"
-#include <nrfx/hal/nrf_qspi.h>
+#include <hal/nrf_qspi.h>
 
 #if MYNEWT_VAL(QSPI_FLASH_SECTOR_SIZE) < 1
 #error QSPI_FLASH_SECTOR_SIZE must be set to the correct value in bsp syscfg.yml
