@@ -31,15 +31,11 @@
  * include board definition file which includes: cmsis-core/core_cm4.h
  * this fixes missing CORTEX_M* definition in cmsis_nvic.c
  */
-#include "mcu/kinetis_common.h"
+#include <fsl_device_registers.h>
 #ifdef __cplusplus
 extern "C" {
 #endif
 
-void NVIC_Relocate(void);
-void NVIC_SetVector(IRQn_Type IRQn, uint32_t vector);
-uint32_t NVIC_GetVector(IRQn_Type IRQn);
-
 #ifdef __cplusplus
 }
 #endif
