@@ -154,6 +154,9 @@ extern const struct stm32_hal_i2c_cfg os_bsp_i2c1_cfg;
 #if MYNEWT_VAL(I2C_2)
 extern const struct stm32_hal_i2c_cfg os_bsp_i2c2_cfg;
 #endif
+#if MYNEWT_VAL(I2C_3)
+extern const struct stm32_hal_i2c_cfg os_bsp_i2c3_cfg;
+#endif
 
 #if MYNEWT_VAL(BUS_DRIVER_PRESENT)
 
@@ -270,6 +273,32 @@ static const struct stm32_hal_spi_cfg os_bsp_spi3_cfg = {
 };
 #endif
 #endif
+#if (MYNEWT_VAL(SPI_4_MASTER) || MYNEWT_VAL(SPI_4_SLAVE))
+#if MYNEWT_VAL(SPI_4_CUSTOM_CFG)
+extern const struct stm32_hal_spi_cfg os_bsp_spi4_cfg;
+#else
+static const struct stm32_hal_spi_cfg os_bsp_spi4_cfg = {
+    .sck_pin = MYNEWT_VAL(SPI_4_PIN_SCK),
+    .mosi_pin = MYNEWT_VAL(SPI_4_PIN_MOSI),
+    .miso_pin = MYNEWT_VAL(SPI_4_PIN_MISO),
+    .ss_pin = MYNEWT_VAL(SPI_4_PIN_SS),
+    .irq_prio = 2,
+};
+#endif
+#endif
+#if (MYNEWT_VAL(SPI_5_MASTER) || MYNEWT_VAL(SPI_5_SLAVE))
+#if MYNEWT_VAL(SPI_5_CUSTOM_CFG)
+extern const struct stm32_hal_spi_cfg os_bsp_spi5_cfg;
+#else
+static const struct stm32_hal_spi_cfg os_bsp_spi5_cfg = {
+    .sck_pin = MYNEWT_VAL(SPI_5_PIN_SCK),
+    .mosi_pin = MYNEWT_VAL(SPI_5_PIN_MOSI),
+    .miso_pin = MYNEWT_VAL(SPI_5_PIN_MISO),
+    .ss_pin = MYNEWT_VAL(SPI_5_PIN_SS),
+    .irq_prio = 2,
+};
+#endif
+#endif
 #endif
 
 #if MYNEWT_VAL(ETH_0)
@@ -472,6 +501,10 @@ stm32_periph_create_i2c(void)
     rc = hal_i2c_init(2, (void *)&os_bsp_i2c2_cfg);
     assert(rc == 0);
 #endif
+#if MYNEWT_VAL(I2C_3)
+    rc = hal_i2c_init(3, (void *)&os_bsp_i2c3_cfg);
+    assert(rc == 0);
+#endif
 }
 
 #if MYNEWT_VAL(BUS_DRIVER_PRESENT)
@@ -554,6 +587,22 @@ stm32_periph_create_spi(void)
     rc = hal_spi_init(3, (void *)&os_bsp_spi3_cfg, HAL_SPI_TYPE_SLAVE);
     assert(rc == 0);
 #endif
+#if MYNEWT_VAL(SPI_4_MASTER)
+    rc = hal_spi_init(4, (void *)&os_bsp_spi4_cfg, HAL_SPI_TYPE_MASTER);
+    assert(rc == 0);
+#endif
+#if MYNEWT_VAL(SPI_4_SLAVE)
+    rc = hal_spi_init(4, (void *)&os_bsp_spi4_cfg, HAL_SPI_TYPE_SLAVE);
+    assert(rc == 0);
+#endif
+#if MYNEWT_VAL(SPI_5_MASTER)
+    rc = hal_spi_init(5, (void *)&os_bsp_spi5_cfg, HAL_SPI_TYPE_MASTER);
+    assert(rc == 0);
+#endif
+#if MYNEWT_VAL(SPI_5_SLAVE)
+    rc = hal_spi_init(5, (void *)&os_bsp_spi5_cfg, HAL_SPI_TYPE_SLAVE);
+    assert(rc == 0);
+#endif
 }
 #endif
 
