@@ -38,8 +38,12 @@
 
 #if MYNEWT_VAL(BOOT_LOADER)
 #define BOOT_LOADER     1
+#define FLASH_AREA_IMAGE FLASH_AREA_IMAGE_0
 #else
 #define BOOT_LOADER     0
+#ifdef FLASH_AREA_IMAGE_1
+#define FLASH_AREA_IMAGE FLASH_AREA_IMAGE_1
+#endif
 #endif
 
 #define FAT_TYPE_FAT12              12
@@ -49,7 +53,6 @@
 #define FAT_COUNT                   1
 #define SECTOR_COUNT                (MYNEWT_VAL(MSC_FAT_VIEW_DISK_SIZE) * 2)
 
-#define SECTOR_SIZE                 512
 #define SECTORS_PER_CLUSTER         (MYNEWT_VAL(MSC_FAT_VIEW_SECTORS_PER_CLUSTER))
 #define CLUSTER_SIZE                ((SECTOR_SIZE) * (SECTORS_PER_CLUSTER))
 
@@ -200,9 +203,6 @@ typedef struct dir_entry {
     cluster_t first_cluster;
 } dir_entry_t;
 
-/* If true, test image will be confirmed on root directory read */
-static bool auto_confirm;
-
 struct fat_chain fat_chains[32];
 /* Number of chains in fat_chains array */
 uint8_t fat_chain_count;
@@ -214,26 +214,14 @@ static uint8_t root_dir_entry_count;
 
 static scsi_cmd_type_t last_scsi_command;
 
-static enum {
+typedef enum {
     MEDIUM_NOT_PRESENT,
     REPORT_MEDIUM_CHANGE,
     MEDIUM_RELOAD,
     MEDIUM_PRESENT,
-} medium_state;
-
-struct unallocated_write {
-    uint32_t first_sector;
-    uint32_t last_sector;
-    enum {
-        NOT_TOUCHED_YET = 0,
-        WRITE_IN_PROGRESS = 1,
-        NOT_AN_IMAGE = -1,
-        CURRENT_IMAGE_NOT_CONFIRMED = -2,
-        WRITE_EXCEEDED_SPACE = -3,
-        WRITE_NOT_IN_SEQUENCE = -4,
-    } write_status;
-} unallocated_write;
+} medium_state_t;
 
+static medium_state_t medium_state;
 
 static uint32_t
 return0(const file_entry_t *file)
@@ -258,275 +246,6 @@ static const file_entry_t volume_label = {
     .read_sector = empty_read,
 };
 
-static const char mynewt_htm_text[] =
-    "<!-- mynewt Website and Authentication Shortcut -->\n"
-    "<html>\n"
-    "<head>\n"
-    "<meta http-equiv=\"refresh\" content=\"0; url=https://mynewt.apache.org/\"/>\n"
-    "<title>mynewt Website Shortcut</title>\n"
-    "</head>\n"
-    "<body></body>\n"
-    "</html>";
-
-static uint32_t
-mynewt_htm_size(const file_entry_t *file)
-{
-    (void)file;
-
-    return strlen(mynewt_htm_text);
-}
-
-static void
-mynewt_htm_read(const struct file_entry *entry, uint32_t file_sector, uint8_t buffer[512])
-{
-    (void)entry;
-
-    if (file_sector == 0) {
-        strcpy((char *)buffer, mynewt_htm_text);
-        memset(buffer + 512 - sizeof(mynewt_htm_text), 0, sizeof(mynewt_htm_text));
-    } else {
-        memset(buffer, 0, 512);
-    }
-}
-
-static const file_entry_t mynew_htm = {
-    .name = "MYNEWT.HTM",
-    .attributes = FAT_FILE_ENTRY_ATTRIBUTE_READ_ONLY,
-    .size = mynewt_htm_size,
-    .read_sector = mynewt_htm_read,
-};
-
-static const char readme_text[] = "This device runs "
-                                  MYNEWT_VAL(MSC_FAT_VIEW_DEFAULT_README_APP_NAME)  " on "
-                                  MYNEWT_VAL(BSP_NAME);
-
-#if defined MYNEWT_VAL_REPO_VERSION_APACHE_MYNEWT_CORE
-#define REPO_VERSION_APACHE_MYNEWT_CORE     MYNEWT_VAL(REPO_VERSION_APACHE_MYNEWT_CORE)
-#else
-#define REPO_VERSION_APACHE_MYNEWT_CORE     "unknown"
-#endif
-
-#if defined MYNEWT_VAL_REPO_HASH_APACHE_MYNEWT_CORE
-#define REPO_HASH_APACHE_MYNEWT_CORE        MYNEWT_VAL(REPO_HASH_APACHE_MYNEWT_CORE)
-#else
-#define REPO_HASH_APACHE_MYNEWT_CORE        ""
-#endif
-
-#if defined MYNEWT_VAL_REPO_VERSION_APACHE_MYNEWT_NIMBLE
-#define REPO_VERSION_APACHE_MYNEWT_NIMBLE   MYNEWT_VAL(REPO_VERSION_APACHE_MYNEWT_NIMBLE)
-#else
-#define REPO_VERSION_APACHE_MYNEWT_NIMBLE   "unknown"
-#endif
-
-#if defined MYNEWT_VAL_REPO_HASH_APACHE_MYNEWT_NIMBLE
-#define REPO_HASH_APACHE_MYNEWT_NIMBLE      MYNEWT_VAL(REPO_HASH_APACHE_MYNEWT_NIMBLE)
-#else
-#define REPO_HASH_APACHE_MYNEWT_NIMBLE      ""
-#endif
-
-#if defined MYNEWT_VAL_REPO_VERSION_APACHE_MYNEWT_MCUMGR
-#define REPO_VERSION_APACHE_MYNEWT_MCUMGR   MYNEWT_VAL(REPO_VERSION_APACHE_MYNEWT_MCUMGR)
-#else
-#define REPO_VERSION_APACHE_MYNEWT_MCUMGR   "unknown"
-#endif
-
-#if defined MYNEWT_VAL_REPO_HASH_APACHE_MYNEWT_MCUMGR
-#define REPO_HASH_APACHE_MYNEWT_MCUMGR      MYNEWT_VAL(REPO_HASH_APACHE_MYNEWT_MCUMGR)
-#else
-#define REPO_HASH_APACHE_MYNEWT_MCUMGR      ""
-#endif
-
-#if defined MYNEWT_VAL_REPO_VERSION_TINYUSB
-#define REPO_VERSION_TINYUSB                MYNEWT_VAL(REPO_VERSION_TINYUSB)
-#else
-#define REPO_VERSION_TINYUSB                "unknown"
-#endif
-
-#if defined MYNEWT_VAL_REPO_HASH_TINYUSB
-#define REPO_HASH_TINYUSB                   MYNEWT_VAL(REPO_HASH_TINYUSB)
-#else
-#define REPO_HASH_TINYUSB                   ""
-#endif
-
-static int
-readme_create_content(struct MemFile *file)
-{
-    struct image_header image_header;
-    const struct flash_area *fa;
-
-    fwrite(readme_text, 1, sizeof(readme_text) - 1, &file->file);
-
-    if (0 == flash_area_open(FLASH_AREA_IMAGE_0, &fa)) {
-        flash_area_read(fa, 0, &image_header, sizeof(image_header));
-        if (image_header.ih_magic == IMAGE_MAGIC) {
-            fprintf(&file->file, "\n\nApp version: %u.%u.%u.%u\n", image_header.ih_ver.iv_major,
-                    image_header.ih_ver.iv_minor,
-                    image_header.ih_ver.iv_revision,
-                    (unsigned)image_header.ih_ver.iv_build_num);
-        }
-        flash_area_close(fa);
-    }
-
-    if (MYNEWT_VAL(MSC_FAT_VIEW_DEFAULT_README_INCLUDE_HASHES)) {
-        fprintf(&file->file, "\n\nmynewt: " REPO_VERSION_APACHE_MYNEWT_CORE " " REPO_HASH_APACHE_MYNEWT_CORE);
-        fprintf(&file->file, "\nnimble: " REPO_VERSION_APACHE_MYNEWT_NIMBLE " " REPO_HASH_APACHE_MYNEWT_NIMBLE);
-        fprintf(&file->file, "\nmcumgr: " REPO_VERSION_APACHE_MYNEWT_MCUMGR " " REPO_HASH_APACHE_MYNEWT_MCUMGR);
-        fprintf(&file->file, "\ntinyusb: " REPO_VERSION_TINYUSB " " REPO_HASH_TINYUSB);
-    }
-    if (MYNEWT_VAL(MSC_FAT_VIEW_HUGE_FILE)) {
-        fprintf(&file->file, "\n\n'Huge file' can be used to verify USB performance.\n");
-    }
-
-    fprintf(&file->file, "\n\nNew firmware can be copied to this drive (drag-drop .img file to upgrade device).\n");
-
-    return file->bytes_written;
-}
-
-static uint32_t
-readme_size(const file_entry_t *file_entry)
-{
-    (void)file_entry;
-    struct MemFile empty_mem_file;
-    uint32_t len;
-
-    fmemopen_w(&empty_mem_file, (char *)NULL, 0);
-    len = readme_create_content(&empty_mem_file);
-
-    return len;
-}
-
-static void
-readme_read(const struct file_entry *entry, uint32_t file_sector, uint8_t buffer[512])
-{
-    struct MemFile sector_file;
-    int written = 0;
-    (void)entry;
-
-    MSC_FAT_VIEW_LOG_DEBUG("Readme read %d\n", file_sector);
-    if (file_sector == 0) {
-        fmemopen_w(&sector_file, (char *)buffer, 512);
-        readme_create_content(&sector_file);
-        written = sector_file.bytes_written;
-    }
-
-    memset(buffer + written, 0, 512 - written);
-}
-
-static const file_entry_t readme = {
-    .name = "README.TXT",
-    .attributes = FAT_FILE_ENTRY_ATTRIBUTE_READ_ONLY,
-    .size = readme_size,
-    .read_sector = readme_read,
-};
-
-static uint32_t
-slot0_img_size(const file_entry_t *file)
-{
-    struct image_header image_header;
-    struct image_tlv_info tlv_info;
-    uint32_t size = 0;
-    const struct flash_area *fa;
-    (void)file;
-
-    if (0 == flash_area_open(FLASH_AREA_IMAGE_0, &fa)) {
-        flash_area_read(fa, 0, &image_header, sizeof(image_header));
-        size = image_header.ih_img_size + image_header.ih_hdr_size;
-        flash_area_read(fa, size, &tlv_info, sizeof(tlv_info));
-        if (tlv_info.it_magic == IMAGE_TLV_INFO_MAGIC) {
-            size += tlv_info.it_tlv_tot;
-        }
-        flash_area_close(fa);
-    }
-
-    return size;
-}
-
-static void
-slot0_img_read(const struct file_entry *entry, uint32_t file_sector, uint8_t buffer[512])
-{
-    const struct flash_area *fa;
-    uint32_t addr;
-    (void)entry;
-
-    if (0 == flash_area_open(FLASH_AREA_IMAGE_0, &fa)) {
-        addr = file_sector * 512;
-        flash_area_read(fa, addr, buffer, 512);
-        flash_area_close(fa);
-    }
-}
-
-static const file_entry_t slot0 = {
-    .name = "FIRMWARE.IMG",
-    .attributes = FAT_FILE_ENTRY_ATTRIBUTE_READ_ONLY,
-    .size = slot0_img_size,
-    .read_sector = slot0_img_read,
-};
-
-static uint32_t
-slot0_hex_size(const file_entry_t *file)
-{
-    uint32_t size = 0;
-    const struct flash_area *fa;
-    (void)file;
-
-    if (0 == flash_area_open(FLASH_AREA_IMAGE_0, &fa)) {
-        size = fa->fa_size * 4;
-        flash_area_close(fa);
-    }
-
-    return size;
-}
-
-static uint8_t
-hex_digit(int v)
-{
-    v &= 0xF;
-
-    return (v < 10) ? (v + '0') : (v + 'A' - 10);
-}
-
-static void
-slot0_hex_read(const struct file_entry *entry, uint32_t file_sector, uint8_t buffer[512])
-{
-    const struct flash_area *fa;
-    int i;
-    int j;
-    int k;
-    uint32_t addr = (file_sector * 512) / 4;
-    uint32_t addr_buf;
-    (void)entry;
-
-    if (0 == flash_area_open(FLASH_AREA_IMAGE_0, &fa)) {
-        flash_area_read(fa, addr, buffer, 512 / 4);
-        flash_area_close(fa);
-        for (i = 512, j = 128; i > 0;) {
-            buffer[--i] = '\n';
-            buffer[--i] = '\r';
-            for (k = 0; k < 16; ++k) {
-                buffer[--i] = hex_digit(buffer[--j]);
-                buffer[--i] = hex_digit(buffer[j] >> 4);
-                buffer[--i] = ' ';
-            }
-            for (k = 0; k < 5; ++k) {
-                buffer[--i] = ' ';
-            }
-            buffer[--i] = ':';
-            addr_buf = addr + j;
-            for (k = 0; k < 8; ++k) {
-                buffer[--i] = hex_digit(addr_buf);
-                addr_buf >>= 4;
-            }
-        }
-    }
-}
-
-static const file_entry_t slot0_hex = {
-    .name = "SLOT0.HEX",
-    .attributes = FAT_FILE_ENTRY_ATTRIBUTE_READ_ONLY,
-    .size = slot0_hex_size,
-    .read_sector = slot0_hex_read,
-};
-
 static const file_entry_t system_volume_information = {
     .name = "System Volume Information",
     .attributes = FAT_FILE_ENTRY_ATTRIBUTE_ARCHIVE |
@@ -543,29 +262,6 @@ static const file_entry_t drop_image_here = {
     .read_sector = empty_read,
 };
 
-static uint32_t
-huge_file_size(const file_entry_t *file)
-{
-    (void)file;
-
-    return HUGE_FILE_SIZE;
-}
-
-static void
-huge_file_read(const struct file_entry *entry, uint32_t file_sector, uint8_t buffer[512])
-{
-    (void)entry;
-
-    memset(buffer, (uint8_t)file_sector, 512);
-}
-
-static const file_entry_t huge_file = {
-    .name = "Huge file",
-    .attributes = FAT_FILE_ENTRY_ATTRIBUTE_READ_ONLY,
-    .size = huge_file_size,
-    .read_sector = huge_file_read,
-};
-
 static int write_status;
 static const char *write_result_text[] = {
     "File that was written was not a valid image.",
@@ -614,7 +310,7 @@ flash_result_read(const struct file_entry *entry, uint32_t file_sector, uint8_t
     memset(buffer + written, 0, 512 - written);
 }
 
-static const file_entry_t flash_result = {
+const file_entry_t flash_result = {
     .name = "Write error.txt",
     .attributes = FAT_FILE_ENTRY_ATTRIBUTE_READ_ONLY,
     .size = flash_result_size,
@@ -910,10 +606,17 @@ void
 msc_fat_view_add_dir_entry(const file_entry_t *file)
 {
     int entry_ix = root_dir_entry_count++;
+    medium_state_t state = medium_state;
 
+    if (state != MEDIUM_NOT_PRESENT) {
+        medium_state = MEDIUM_NOT_PRESENT;
+    }
     root_dir[entry_ix].file = file;
     root_dir[entry_ix].dir_slots = fat_dir_entry_slots(file->name);
     MSC_FAT_VIEW_LOG_DEBUG("Added root entry %s\n", file->name);
+    if (state != MEDIUM_NOT_PRESENT) {
+        medium_state = MEDIUM_RELOAD;
+    }
 }
 
 void
@@ -1284,10 +987,6 @@ msc_fat_view_read_root_sector(uint16_t dir_sector, uint8_t buffer[512])
         dst++;
     }
     memset(dst, 0xE5, buffer + 512 - (uint8_t *)dst);
-    if (auto_confirm) {
-        img_mgmt_state_confirm();
-        auto_confirm = false;
-    }
 }
 
 static void
@@ -1346,46 +1045,28 @@ msc_fat_view_write_fat_sector(uint32_t fat_sector, const uint8_t *buffer)
     return 512;
 }
 
+msc_fat_view_write_handler_t *current_write_handler;
+
 static void
 msc_fat_view_handle_new_file(const fat_dir_entry_t *entry, const char *name)
 {
     cluster_t cluster;
     uint32_t sector;
     fat_chain_t *chain;
-    struct image_version version;
-    uint32_t flags;
+    int rc;
 
-    MSC_FAT_VIEW_LOG_INFO("Handle new file (%d) %s %d %d\n", (int)unallocated_write.write_status, name,
+    MSC_FAT_VIEW_LOG_INFO("Handle new file %s %d %d\n", name,
                           (int)entry->cluster_lo, (int)entry->size);
     /* new entry with start cluster and file size */
     if (entry->cluster_lo != 0 && entry->size > 0) {
         cluster = le16toh(entry->cluster_lo);
         sector = cluster_to_sector(cluster);
         chain = fat_chain_find(cluster);
-        if (unallocated_write.write_status == WRITE_IN_PROGRESS) {
-            if (unallocated_write.first_sector == sector && chain && chain->first == cluster) {
-                MSC_FAT_VIEW_LOG_INFO("New file detected\n");
-                if (BOOT_LOADER) {
-                    img_mgmt_state_confirm();
-                    hal_system_reset();
-                } else {
-                    if (img_mgmt_read_info(1, &version, NULL, &flags) == 0) {
-                        MSC_FAT_VIEW_LOG_INFO("New image OK, resetting\n");
-                        img_mgmt_state_set_pending(1, 0);
-                        hal_system_reset();
-                    } else {
-                        MSC_FAT_VIEW_LOG_ERROR("New file not an valid image\n");
-                    }
-                }
-            } else {
-                MSC_FAT_VIEW_LOG_ERROR(
-                    "New file not ready to flash new sectors (%d-%d), file start cluster %d (sector %d) %d\n",
-                    unallocated_write.first_sector, unallocated_write.last_sector, cluster, sector, fat_chain_count);
-            }
-        } else {
-            if ((int)unallocated_write.write_status < 0) {
-                MSC_FAT_VIEW_LOG_ERROR("Write failed, reloading medium\n");
-                medium_state = MEDIUM_RELOAD;
+        if (current_write_handler) {
+            rc = current_write_handler->file_written(current_write_handler, entry->size,
+                                                     sector, chain && chain->first == cluster);
+            if (rc) {
+                current_write_handler = NULL;
             }
         }
     }
@@ -1479,68 +1160,36 @@ msc_fat_view_write_root_sector(uint32_t sector, const uint8_t *buffer)
 }
 
 static int
-msc_fat_view_write_unallocated_sector(uint32_t sector, const uint8_t *buffer)
+msc_fat_view_write_unallocated_sector(uint32_t sector, uint8_t *buffer)
 {
-    const struct flash_area *fa;
-    uint32_t write_offset;
-    int rc;
+    int res;
 
-    if (unallocated_write.write_status < 0) {
-        return 512;
-    }
-    flash_area_open(BOOT_LOADER ? FLASH_AREA_IMAGE_0 : FLASH_AREA_IMAGE_1, &fa);
-    if (unallocated_write.write_status == NOT_TOUCHED_YET) {
-        if (BOOT_LOADER) {
-            if (((struct image_header *)buffer)->ih_magic == IMAGE_MAGIC) {
-                unallocated_write.write_status = WRITE_IN_PROGRESS;
-                /* TODO: unmount and add error file */
+    msc_fat_view_write_handler_t *write_handler = current_write_handler;
 
-            }
-        } else if ((img_mgmt_state_flags(0) & IMG_MGMT_STATE_F_CONFIRMED) == 0) {
-            MSC_FAT_VIEW_LOG_ERROR("Image not confirmed, write rejected\n");
-
-            /* Image in slot 0 not confirmed, do not write */
-            unallocated_write.write_status = CURRENT_IMAGE_NOT_CONFIRMED;
-        } else if (((struct image_header *)buffer)->ih_magic == IMAGE_MAGIC) {
-            unallocated_write.write_status = WRITE_IN_PROGRESS;
-        }
-        if (unallocated_write.write_status == WRITE_IN_PROGRESS) {
-            MSC_FAT_VIEW_LOG_INFO("Image writing detected\n");
-            unallocated_write.first_sector = sector;
-            unallocated_write.last_sector = sector;
-        }
-    } else if (unallocated_write.write_status == WRITE_IN_PROGRESS) {
-        if (sector != unallocated_write.last_sector + 1) {
-            /*
-             * Unallocated space written without order, code will not be able to used
-             * it sensible.
-             */
-            unallocated_write.write_status = WRITE_NOT_IN_SEQUENCE;
-            MSC_FAT_VIEW_LOG_ERROR("Not continuous writes to unallocated space rejected\n");
+    if (write_handler) {
+        res = write_handler->write_sector(write_handler, sector, buffer);
+        if (res == 512) {
+            return 512;
         }
     }
-    if (unallocated_write.write_status == WRITE_IN_PROGRESS) {
-        write_offset = (sector - unallocated_write.first_sector) * SECTOR_SIZE;
-        if (!hal_flash_isempty_no_buf(fa->fa_device_id, fa->fa_off + write_offset, SECTOR_SIZE)) {
-            flash_area_erase(fa, write_offset, SECTOR_SIZE);
+    FOR_TABLE(msc_fat_view_write_handler_t *, p, msc_fat_view_write_handlers) {
+        if (*p == current_write_handler) {
+            continue;
         }
-
-        if ((rc = flash_area_write(fa, write_offset, buffer, SECTOR_SIZE)) < 0) {
-            MSC_FAT_VIEW_LOG_ERROR("Flash write error, following writes will be rejected %d 0x%08x\n",
-                                   rc, fa->fa_off + write_offset);
-            unallocated_write.write_status = WRITE_EXCEEDED_SPACE;
+        write_handler = *p;
+        res = write_handler->write_sector(write_handler, sector, buffer);
+        if (res == 512) {
+            current_write_handler = write_handler;
+            return 512;
         }
     }
-    flash_area_close(fa);
-    if (unallocated_write.write_status == WRITE_IN_PROGRESS) {
-        unallocated_write.last_sector = sector;
-    }
+    current_write_handler = NULL;
 
     return 512;
 }
 
 static int
-msc_fat_view_write_file_sector(dir_entry_t *dir_entry, uint32_t file_sector, const uint8_t *buffer)
+msc_fat_view_write_file_sector(dir_entry_t *dir_entry, uint32_t file_sector, uint8_t *buffer)
 {
     if (dir_entry->file->write_sector) {
         dir_entry->file->write_sector(dir_entry->file, file_sector, buffer);
@@ -1549,7 +1198,7 @@ msc_fat_view_write_file_sector(dir_entry_t *dir_entry, uint32_t file_sector, con
 }
 
 static int
-msc_fat_view_write_normal_sector(uint32_t sector, const uint8_t *buffer)
+msc_fat_view_write_normal_sector(uint32_t sector, uint8_t *buffer)
 {
     cluster_t cluster;
     cluster_t cluster_in_chain;
@@ -1569,37 +1218,29 @@ msc_fat_view_write_normal_sector(uint32_t sector, const uint8_t *buffer)
     return res;
 }
 
+static void
+add_dir_entry(file_entry_t **entry)
+{
+    if ((*entry)->valid == NULL || (*entry)->valid(*entry) == MSC_FAT_VIEW_FILE_ENTRY_VALID) {
+        msc_fat_view_add_dir_entry(*entry);
+    }
+}
+
 static void
 init_disk_data(void)
 {
     root_dir_entry_count = 0;
 
-    if (MYNEWT_VAL(MSC_FAT_VIEW_AUTOCONFIRM)) {
-        auto_confirm = ((img_mgmt_state_flags(0) & IMG_MGMT_STATE_F_CONFIRMED) == 0);
-    }
     msc_fat_view_add_dir_entry(&volume_label);
     if (MYNEWT_VAL(MSC_FAT_VIEW_SYSTEM_VOLUME_INFORMATION)) {
         msc_fat_view_add_dir_entry(&system_volume_information);
     }
 
-    if (MYNEWT_VAL(MSC_FAT_VIEW_MYNEWT_SHORTCUT)) {
-        msc_fat_view_add_dir_entry(&mynew_htm);
-    }
-    if (MYNEWT_VAL(MSC_FAT_VIEW_DEFAULT_README)) {
-        msc_fat_view_add_dir_entry(&readme);
-    }
     if (MYNEWT_VAL(MSC_FAT_VIEW_DROP_IMAGE_HERE)) {
         msc_fat_view_add_dir_entry(&drop_image_here);
     }
-    if (MYNEWT_VAL(MSC_FAT_VIEW_SLOT0_IMAGE)) {
-        msc_fat_view_add_dir_entry(&slot0);
-    }
-    if (MYNEWT_VAL(MSC_FAT_VIEW_SLOT0_HEX)) {
-        msc_fat_view_add_dir_entry(&slot0_hex);
-    }
-    if (MYNEWT_VAL(MSC_FAT_VIEW_HUGE_FILE)) {
-        msc_fat_view_add_dir_entry(&huge_file);
-    }
+    FOR_EACH_ENTRY(file_entry_t *, msc_fat_view_root_entry, add_dir_entry);
+
     if (MYNEWT_VAL(MSC_FAT_VIEW_COREDUMP_FILES)) {
         msc_fat_view_add_coredumps();
     }
@@ -1613,12 +1254,6 @@ update_disk_data(void)
     free_clusters = (cluster_t)((SECTOR_COUNT - FAT_CLUSTER2_FIRST_SECTOR) / SECTORS_PER_CLUSTER);
     fat_chain_count = 0;
 
-    if (unallocated_write.write_status < 0) {
-        write_status = unallocated_write.write_status;
-        msc_fat_view_add_dir_entry(&flash_result);
-    }
-    unallocated_write.write_status = NOT_TOUCHED_YET;
-
     for (i = 0; i < root_dir_entry_count; ++i) {
         msc_fat_view_update_dir_entry(i);
     }
@@ -1817,9 +1452,23 @@ tud_msc_scsi_cb(uint8_t lun, uint8_t const scsi_cmd[16], void *buffer, uint16_t
 }
 
 void
-msc_fat_view_pkg_init(void)
+msc_fat_view_media_eject(void)
+{
+    medium_state = MEDIUM_NOT_PRESENT;
+}
+
+void
+msc_fat_view_media_insert(void)
 {
     medium_state = MEDIUM_RELOAD;
+}
+
+void
+msc_fat_view_pkg_init(void)
+{
+    if (MYNEWT_VAL(MSC_FAT_VIEW_AUTO_INSERT)) {
+        msc_fat_view_media_insert();
+    }
     init_disk_data();
 }
 
