@@ -50,6 +50,10 @@
 #include "os/mynewt.h"
 #include "log/log.h"
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 #define MODLOG_MODULE_DFLT      255
 
 /**
@@ -547,4 +551,8 @@ modlog_hexdump(uint8_t module, uint8_t level,
 
 #endif
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif
